﻿using HeuristicLab.Clients.Access.Administration;
using HeuristicLab.Clients.Hive.WebJobManager.Services;
using HeuristicLab.Clients.Hive.WebJobManager.ViewModels.User;
using Microsoft.AspNet.Hosting;
using Microsoft.AspNet.Http;
using Microsoft.AspNet.Mvc;
using System;
using System.Collections.Generic;
using System.Linq;
using System.ServiceModel.Security;
using System.Threading.Tasks;

namespace HeuristicLab.Clients.Hive.WebJobManager.Controllers
{
    public class UserController : Controller
    {
        private WebLoginService weblog;
        private HiveServiceLocatorWeb serviceLocator;
        private AccessAdministrationClient accessClient;
        private Guid userId;

        private IHostingEnvironment _environment;

        public UserController(IHostingEnvironment env)
        {
            weblog = WebLoginService.Instance;
            _environment = env;
        }
        #region Users
        private void init()
        {
            var u = HttpContext.Session.GetString("UserId");
            if (u == null || u == "" || Guid.Parse(u) == Guid.Empty)
            {
                userId = Guid.Empty;
                serviceLocator = new HiveServiceLocatorWeb();
            }
            else
            {
                userId = Guid.Parse(u);
                serviceLocator = weblog.getServiceLocator(userId);
                accessClient = weblog.getAccessAdminClient(userId);
            }
        }
        public IActionResult Index()
        {
            init();
            if (serviceLocator.CheckLogin())
            {

                ViewBag.Title = "Users";
                UserViewModel vm = new UserViewModel(accessClient).refreshUsers();
                ViewBag.SessionId = HttpContext.Session.GetString("UserId");
                return View("Index", vm);
            }
            else
            {
                return RedirectToAction("Index", "Home");
            }
        }

        public IActionResult SelectUser(string id)
        {
            init();
            if (serviceLocator.CheckLogin())
            {
                Guid curr = Guid.Parse(id);
                
                UserViewModel vm = new UserViewModel(accessClient).refreshUsers();
                if (curr == Guid.Empty)
                {
                    ViewBag.Title = "Add User";
                }
                else
                {
                    vm.SelectedUser = vm.getUserById(curr);
                    ViewBag.title = vm.SelectedUser.UserName;
                }
                ViewBag.Title += " - Users";
                ViewBag.SessionId = HttpContext.Session.GetString("UserId");
                return View("Index", vm);
            }
            else
            {
                return RedirectToAction("Index", "Home");
            }
        }
        [HttpPost]
        public IActionResult saveUser(string inpusername, string inpfullname, string inpemail, string u)
        {
            init();
            var uid = Guid.Parse(u);
            Access.User user;
            if (uid == Guid.Empty)
                user = new Access.User();
            else
                user = accessClient.Users.Find(x => x.Id == uid);

            user.Id = uid;
            user.UserName = inpusername;
            user.FullName = inpfullname;
            user.Email = inpemail;


            if (uid == Guid.Empty)
            {
                uid = accessClient.addUser(user);
                ViewBag.Title = inpusername + " added - User";
            }
            else
            {
                accessClient.updateUser(user);
                ViewBag.Title = inpusername + " updated - User";
            }

            return RedirectToAction( "SelectUser", new {  id =  uid.ToString()});

        }

        #endregion

        #region Groups
        public IActionResult Groups()
        {
            init();
            if (serviceLocator.CheckLogin())
            {

                ViewBag.Title = "Groups";
                // accessClient.RefreshUsers();
                
                return View("Groups");
            }
            else
            {
                return RedirectToAction("Index", "Home");
            }
        }
        #endregion
        #region Roles
        public IActionResult Roles()
        {
            init();
            if (serviceLocator.CheckLogin())
            {

                ViewBag.Title = "Roles";
                // accessClient.RefreshUsers();

                return View("Roles");
            }
            else
            {
                return RedirectToAction("Index", "Home");
            }
        }
        #endregion
    }
}
